pub struct Optimizer { /* private fields */ }Expand description
The plan optimizer: runs a set of rules iteratively until convergence.
Implementations
Sourceimpl Optimizer
impl Optimizer
Sourcepub fn default_rules() -> Self
pub fn default_rules() -> Self
Create an optimizer with the default set of rules.
Sourcepub fn with_rules(rules: Vec<Box<dyn OptimizationRule>>) -> Self
pub fn with_rules(rules: Vec<Box<dyn OptimizationRule>>) -> Self
Create an optimizer with a custom set of rules.
Sourcepub fn optimize(&self, plan: LogicalPlan) -> (LogicalPlan, usize)
pub fn optimize(&self, plan: LogicalPlan) -> (LogicalPlan, usize)
Optimize a logical plan by applying rules iteratively.
Returns the optimized plan and the number of passes performed.