OptimizationRule

Trait OptimizationRule 

pub trait OptimizationRule: Send + Sync {
    // Required methods
    fn name(&self) -> &str;
    fn apply(&self, stream: &mut LogicalStream) -> bool;
}
A single optimization rule that can transform a logical stream.

Required Methods

fn name(&self) -> &str

Human-readable name for logging/debugging.

fn apply(&self, stream: &mut LogicalStream) -> bool

Apply the rule to a stream, returning true if any changes were made.

Implementors