pub trait OptimizationRule: Send + Sync {
// Required methods
fn name(&self) -> &str;
fn apply(&self, stream: &mut LogicalStream) -> bool;
}Expand description
A single optimization rule that can transform a logical stream.
Required Methods
Sourcefn apply(&self, stream: &mut LogicalStream) -> bool
fn apply(&self, stream: &mut LogicalStream) -> bool
Apply the rule to a stream, returning true if any changes were made.