pub fn parse(source: &str) -> ParseResult<Program>Expand description
Parse a VPL source string into a Program AST.
Runs pest parsing in a thread with a 16 MB stack to prevent stack overflow from deeply nested or adversarial inputs that trigger deep recursion in the PEG recursive descent parser.